#' datetime related functions
#'
#' @import lubridate
#' @importFrom langeR get_lang
#'
#' @export

get_datetimestr <- function(date,
                            time = NULL,
                            hour = NULL,
                            minute = NULL,
                            second = NULL,
                            fmt = "%Y-%m-%d %H:%M:%S",
                            tz = get_tz()) {
    if (is.null(time) & is.null(hour)) {
        if (!lubridate::is.Date(date)) {
            datetime <- trydatetime(date, modestr = "DT", tz = tz)
        } else {
            datetime <- date
        }
    } else if (!is.null(time)) {
        date <- trydatetime(date, modestr = "D", tz = tz)
        time <- trydatetime(time, modestr = "T", tz = tz)
        datetime <- trydatetime(paste(date, time), modestr = "DT", tz = tz)
    } else {                           # hour must not null
        minute = ifelse(is.null(minute), 0, minute)
        second = ifelse(is.null(second), 0, second)
        date <- trydatetime(date, modestr = "D", tz = tz)
        time <- trydatetime(paste(hour, minute, second, sep = ":"), modestr = "T", tz = tz)
        datetime <- trydatetime(paste(date, time), modestr = "DT", tz = tz)
    }
    return(format(datetime, fmt))
}

#'
#' @export
#'
get_YmdH <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%Y-%m-%d %H", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%Y年%m月%d日%H时", ...))
    }
}

#'
#' @export
#'
get_YmdHcn <- function(...) {
        return(get_YmdH(lang = "cn", ...))
}


#'
#' @export
#'
get_YmdHM <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%Y-%m-%d %H:%M", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%Y年%m月%d日%H:%M", ...))
    }
}

#'
#' @export
#'
get_YmdHMcn <- function(...) {
        return(get_YmdHM(lang = "cn", ...))
}

#'
#' @export
#'
get_YmdHMS <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%Y-%m-%d %H:%M:%S", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%Y年%m月%d日%H: %M:%S", ...))
    }
}

#'
#' @export
#'
get_YmdHMScn <- function(...) {
        return(get_YmdHMS(lang = "cn", ...))
}

#'
#' @export
#'
get_ymdH <- function( lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%y-%m-%d %H", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%y年%m月%d日%H时", ...))
    }
}

#'
#' @export
#'
get_ymdHcn <- function(...) {
        return(get_ymdH(lang = "cn", ...))
}


#'
#' @export
#'
get_ymdHM <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%y-%m-%d %H:%M", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%y年%m月%d日%H:%M", ...))
    }
}

#'
#' @export
#'
get_ymdHMcn <- function(...) {
        return(get_ymdHM(lang = "cn", ...))
}

#'
#' @export
#'
get_ymdHMS <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_datetimestr(fmt = "%y-%m-%d %H:%M:%S", ...))
    }
    if (lang == "cn") {
        return(get_datetimestr(fmt = "%y年%m月%d日%H: %M:%S", ...))
    }
}

#'
#' @export
#'
get_ymdHMScn <- function(...) {
        return(get_ymdHMS(lang = "cn", ...))
}


#'
#' @export
#'
get_YmdHshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%Y%m%d%H", ...))
}

#'
#' @export
#'
get_ymdHshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%y%m%d%H", ...))
}

#'
#' @export
#'
get_YmdHMshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%Y%m%d%H%M", ...))
}

#'
#' @export
#'
get_ymdHMshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%y%m%d%H%M", ...))
}

#'
#' @export
#'
get_YmdHMSshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%Y%m%d%H%M%S", ...))
}

#'
#' @export
#'
get_ymdHMSshort <- function(date, ...) {
    return(get_datetimestr(date, fmt = "%y%m%d%H%M%S", ...))
}

#'
#' @export
#'
get_dH <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%d日%H时", ...))
    } else {
        return(get_datetimestr(date, fmt = "%d %H:00", ...))
    }
}

#'
#' @export
#'
get_dHcn <- function(date, ...) {
    return(get_dH(date, lang = "cn", ...))
}

#'
#' @export
#'
get_mdH <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%m月%d日%H时", ...))
    } else {
        return(get_datetimestr(date, fmt = "%m %d %H:00", ...))
    }
}

#'
#' @export
#'
get_mdHcn <- function(date, ...) {
    return(get_mdH(date, lang = "cn", ...))
}

#'
#' @export
#'
get_dHM <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%d日%H:%M", ...))
    } else {
        return(get_datetimestr(date, fmt = "%d %H:%M", ...))
    }
}

#'
#' @export
#'
get_dHMcn <- function(date, ...) {
    return(get_dHM(date, lang = "cn", ...))
}

#'
#' @export
#'
get_mdHM <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%m月%d日%H:%M", ...))
    } else {
        return(get_datetimestr(date, fmt = "%m %d %H:%M", ...))
    }
}

#'
#' @export
#'
get_mdHMcn <- function(date, ...) {
    return(get_mdHM(date, lang = "cn", ...))
}


#'
#' @export
#'
get_dHMS <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%d日%H:%M:%S", ...))
    } else {
        return(get_datetimestr(date, fmt = "%d %H:%M:%S", ...))
    }
}

#'
#' @export
#'
get_dHMScn <- function(date, ...) {
    return(get_dHMS(date, lang = "cn", ...))
}

#'
#' @export
#'
get_mdHMS <- function(date, lang = langeR::get_lang(), ...) {
    if (lang == "cn") {
        return(get_datetimestr(date, fmt = "%m月%d日%H:%M:%S", ...))
    } else {
        return(get_datetimestr(date, fmt = "%m %d %H:%M:%S", ...))
    }
}

#'
#' @export
#'
get_mdHMScn <- function(date, ...) {
    return(get_mdHMS(date, lang = "cn", ...))
}
