#'
#' @export
#'
get_timestr <- function(time = NULL,
                        hour = NULL,
                        minute = NULL,
                        second = NULL,
                        fmt = "%H:%M:%S", tz = get_tz()) {
    if (!is.null(time)) {
        time <- trydatetime(time, modestr = "T", tz = tz)
    } else if (!is.null(hour)) {
        minute = ifelse(is.null(minute), 0, minute)
        second = ifelse(is.null(second), 0, second)
        time <- trydatetime(paste(hour, minute, second, sep = ":"), modestr = "T", tz = tz)
    } else {
        stop("One of `time` or `hour` should be provided!")
    }
    return(format(time, fmt))
}


#'
#' @export
#'
get_HMS <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_timestr(fmt = "%Y-%m-%d %H:%M:%S", ...))
    }
    if (lang == "cn") {
        return(get_timestr(fmt = "%Y年%m月%d日%H:%M:%S", ...))
    }
}

#'
#' @export
#'
get_HMScn <- function(...) {
        return(get_HMS(lang = "cn", ...))
}

#'
#' @export
#'
get_HM <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_timestr(fmt = "%Y-%m-%d %H:%M", ...))
    }
    if (lang == "cn") {
        return(get_timestr(fmt = "%Y年%m月%d日%H:%M", ...))
    }
}

#'
#' @export
#'
get_HMcn <- function(...) {
        return(get_HM(lang = "cn", ...))
}

#'
#' @export
#'
get_MS <- function(lang = langeR::get_lang(), ...) {
    if (lang == "en") {
        return(get_timestr(fmt = "%Y-%m-%d %M:%S", ...))
    }
    if (lang == "cn") {
        return(get_timestr(fmt = "%Y年%m月%d日%M:%S", ...))
    }
}

#'
#' @export
#'
get_MScn <- function(...) {
        return(get_MS(lang = "cn", ...))
}

